package cc.fascinated.bat.features.base.profile;

import cc.fascinated.bat.common.Profile;
import cc.fascinated.bat.features.Feature;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Fascinated (fascinated7)
 */
public class FeatureProfile extends Profile {
    /**
     * The feature states
     */
    private Map<String, Boolean> featureStates;

    public FeatureProfile() {
        super("feature");
    }

    /**
     * Gets the feature states
     *
     * @return the feature states
     */
    public boolean isFeatureDisabled(Feature feature) {
        if (this.featureStates == null) {
            this.featureStates = new HashMap<>();
        }
        if (feature == null) {
            return false;
        }
        String featureName = feature.getName().toUpperCase();
        if (!this.featureStates.containsKey(featureName)) {
            this.featureStates.put(featureName, false);
        }
        return this.featureStates.get(featureName);
    }

    /**
     * Sets the feature state
     *
     * @param feature the feature to set the state for
     * @param state   the state to set
     */
    public void setFeatureState(Feature feature, boolean state) {
        if (this.featureStates == null) {
            this.featureStates = new HashMap<>();
        }
        this.featureStates.put(feature.getName().toUpperCase(), state);
    }

    @Override
    public void reset() {
        this.featureStates = null;
    }
}
